API docs for “spamfighter.core.commands.apiglue”

# Module s.c.c.apiglue

Part of spamfighter.core.commands View Source

"Клей", позволяющий приклеить нашу систему команд к Twisted-варианту XML-RPC & JSON-RPC.

Function | build_error_translator | Построить декоратор, транслирующий наши исключения в исключения Fault для JSON-RPC/XML-RPC.
Class | API_Glue | Базовый класс, обеспечивающий связь XML-RPC и JSON-RPC реализаций на базе
Class | JSONRPC_API_Glue | Ресурс JSON-RPC (Twisted Web), который обрабатывает команды нашего API (минуя стандартные механизмы поиска функции).
Class | XMLRPC_API_Glue | Ресурс XML-RPC (Twisted Web), который обрабатывает команды нашего API (минуя стандартные механизмы поиска функции).

def build_error_translator(faultClass): (source)
Построить декоратор, транслирующий наши исключения в исключения Fault для JSON-RPC/XML-RPC.